:mod:`API`
----------------------------

``cf-pandas`` Python API
=============================

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation


Top-level API
*************

.. automodule:: cf_pandas
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:
